aboutsummaryrefslogtreecommitdiffstats
path: root/contrib/libs/aws-sdk-cpp/aws-cpp-sdk-s3/include/aws/s3/model/NoncurrentVersionExpiration.h
diff options
context:
space:
mode:
authordakovalkov <dakovalkov@yandex-team.com>2023-12-03 13:33:55 +0300
committerdakovalkov <dakovalkov@yandex-team.com>2023-12-03 14:04:39 +0300
commit2a718325637e5302334b6d0a6430f63168f8dbb3 (patch)
tree64be81080b7df9ec1d86d053a0c394ae53fcf1fe /contrib/libs/aws-sdk-cpp/aws-cpp-sdk-s3/include/aws/s3/model/NoncurrentVersionExpiration.h
parente0d94a470142d95c3007e9c5d80380994940664a (diff)
downloadydb-2a718325637e5302334b6d0a6430f63168f8dbb3.tar.gz
Update contrib/libs/aws-sdk-cpp to 1.11.37
Diffstat (limited to 'contrib/libs/aws-sdk-cpp/aws-cpp-sdk-s3/include/aws/s3/model/NoncurrentVersionExpiration.h')
-rw-r--r--contrib/libs/aws-sdk-cpp/aws-cpp-sdk-s3/include/aws/s3/model/NoncurrentVersionExpiration.h84
1 files changed, 62 insertions, 22 deletions
diff --git a/contrib/libs/aws-sdk-cpp/aws-cpp-sdk-s3/include/aws/s3/model/NoncurrentVersionExpiration.h b/contrib/libs/aws-sdk-cpp/aws-cpp-sdk-s3/include/aws/s3/model/NoncurrentVersionExpiration.h
index 9e966d7722..c039ca9950 100644
--- a/contrib/libs/aws-sdk-cpp/aws-cpp-sdk-s3/include/aws/s3/model/NoncurrentVersionExpiration.h
+++ b/contrib/libs/aws-sdk-cpp/aws-cpp-sdk-s3/include/aws/s3/model/NoncurrentVersionExpiration.h
@@ -29,60 +29,100 @@ namespace Model
* href="http://docs.aws.amazon.com/goto/WebAPI/s3-2006-03-01/NoncurrentVersionExpiration">AWS
* API Reference</a></p>
*/
- class AWS_S3_API NoncurrentVersionExpiration
+ class NoncurrentVersionExpiration
{
public:
- NoncurrentVersionExpiration();
- NoncurrentVersionExpiration(const Aws::Utils::Xml::XmlNode& xmlNode);
- NoncurrentVersionExpiration& operator=(const Aws::Utils::Xml::XmlNode& xmlNode);
+ AWS_S3_API NoncurrentVersionExpiration();
+ AWS_S3_API NoncurrentVersionExpiration(const Aws::Utils::Xml::XmlNode& xmlNode);
+ AWS_S3_API NoncurrentVersionExpiration& operator=(const Aws::Utils::Xml::XmlNode& xmlNode);
- void AddToNode(Aws::Utils::Xml::XmlNode& parentNode) const;
+ AWS_S3_API void AddToNode(Aws::Utils::Xml::XmlNode& parentNode) const;
/**
* <p>Specifies the number of days an object is noncurrent before Amazon S3 can
* perform the associated action. For information about the noncurrent days
* calculations, see <a
* href="https://docs.aws.amazon.com/AmazonS3/latest/dev/intro-lifecycle-rules.html#non-current-days-calculations">How
- * Amazon S3 Calculates When an Object Became Noncurrent</a> in the <i>Amazon
- * Simple Storage Service Developer Guide</i>.</p>
+ * Amazon S3 Calculates When an Object Became Noncurrent</a> in the <i>Amazon S3
+ * User Guide</i>.</p>
*/
inline int GetNoncurrentDays() const{ return m_noncurrentDays; }
/**
* <p>Specifies the number of days an object is noncurrent before Amazon S3 can
* perform the associated action. For information about the noncurrent days
* calculations, see <a
* href="https://docs.aws.amazon.com/AmazonS3/latest/dev/intro-lifecycle-rules.html#non-current-days-calculations">How
- * Amazon S3 Calculates When an Object Became Noncurrent</a> in the <i>Amazon
- * Simple Storage Service Developer Guide</i>.</p>
+ * Amazon S3 Calculates When an Object Became Noncurrent</a> in the <i>Amazon S3
+ * User Guide</i>.</p>
*/
inline bool NoncurrentDaysHasBeenSet() const { return m_noncurrentDaysHasBeenSet; }
/**
* <p>Specifies the number of days an object is noncurrent before Amazon S3 can
* perform the associated action. For information about the noncurrent days
* calculations, see <a
* href="https://docs.aws.amazon.com/AmazonS3/latest/dev/intro-lifecycle-rules.html#non-current-days-calculations">How
- * Amazon S3 Calculates When an Object Became Noncurrent</a> in the <i>Amazon
- * Simple Storage Service Developer Guide</i>.</p>
+ * Amazon S3 Calculates When an Object Became Noncurrent</a> in the <i>Amazon S3
+ * User Guide</i>.</p>
*/
inline void SetNoncurrentDays(int value) { m_noncurrentDaysHasBeenSet = true; m_noncurrentDays = value; }
/**
* <p>Specifies the number of days an object is noncurrent before Amazon S3 can
* perform the associated action. For information about the noncurrent days
* calculations, see <a
* href="https://docs.aws.amazon.com/AmazonS3/latest/dev/intro-lifecycle-rules.html#non-current-days-calculations">How
- * Amazon S3 Calculates When an Object Became Noncurrent</a> in the <i>Amazon
- * Simple Storage Service Developer Guide</i>.</p>
+ * Amazon S3 Calculates When an Object Became Noncurrent</a> in the <i>Amazon S3
+ * User Guide</i>.</p>
*/
inline NoncurrentVersionExpiration& WithNoncurrentDays(int value) { SetNoncurrentDays(value); return *this;}
+
+ /**
+ * <p>Specifies how many noncurrent versions Amazon S3 will retain. If there are
+ * this many more recent noncurrent versions, Amazon S3 will take the associated
+ * action. For more information about noncurrent versions, see <a
+ * href="https://docs.aws.amazon.com/AmazonS3/latest/userguide/intro-lifecycle-rules.html">Lifecycle
+ * configuration elements</a> in the <i>Amazon S3 User Guide</i>.</p>
+ */
+ inline int GetNewerNoncurrentVersions() const{ return m_newerNoncurrentVersions; }
+
+ /**
+ * <p>Specifies how many noncurrent versions Amazon S3 will retain. If there are
+ * this many more recent noncurrent versions, Amazon S3 will take the associated
+ * action. For more information about noncurrent versions, see <a
+ * href="https://docs.aws.amazon.com/AmazonS3/latest/userguide/intro-lifecycle-rules.html">Lifecycle
+ * configuration elements</a> in the <i>Amazon S3 User Guide</i>.</p>
+ */
+ inline bool NewerNoncurrentVersionsHasBeenSet() const { return m_newerNoncurrentVersionsHasBeenSet; }
+
+ /**
+ * <p>Specifies how many noncurrent versions Amazon S3 will retain. If there are
+ * this many more recent noncurrent versions, Amazon S3 will take the associated
+ * action. For more information about noncurrent versions, see <a
+ * href="https://docs.aws.amazon.com/AmazonS3/latest/userguide/intro-lifecycle-rules.html">Lifecycle
+ * configuration elements</a> in the <i>Amazon S3 User Guide</i>.</p>
+ */
+ inline void SetNewerNoncurrentVersions(int value) { m_newerNoncurrentVersionsHasBeenSet = true; m_newerNoncurrentVersions = value; }
+
+ /**
+ * <p>Specifies how many noncurrent versions Amazon S3 will retain. If there are
+ * this many more recent noncurrent versions, Amazon S3 will take the associated
+ * action. For more information about noncurrent versions, see <a
+ * href="https://docs.aws.amazon.com/AmazonS3/latest/userguide/intro-lifecycle-rules.html">Lifecycle
+ * configuration elements</a> in the <i>Amazon S3 User Guide</i>.</p>
+ */
+ inline NoncurrentVersionExpiration& WithNewerNoncurrentVersions(int value) { SetNewerNoncurrentVersions(value); return *this;}
+
private:
int m_noncurrentDays;
- bool m_noncurrentDaysHasBeenSet;
+ bool m_noncurrentDaysHasBeenSet = false;
+
+ int m_newerNoncurrentVersions;
+ bool m_newerNoncurrentVersionsHasBeenSet = false;
};
} // namespace Model
@@ -29,60 +29,100 @@ namespace Model
/**
* <p>Specifies the number of days an object is noncurrent before Amazon S3 can
- * perform the associated action. For information about the noncurrent days
- * calculations, see <a
+ * perform the associated action. The value must be a non-zero positive integer.
+ * For information about the noncurrent days calculations, see <a
* href="https://docs.aws.amazon.com/AmazonS3/latest/dev/intro-lifecycle-rules.html#non-current-days-calculations">How
@@ -29,60 +29,100 @@ namespace Model
/**
* <p>Specifies the number of days an object is noncurrent before Amazon S3 can
- * perform the associated action. For information about the noncurrent days
- * calculations, see <a
+ * perform the associated action. The value must be a non-zero positive integer.
+ * For information about the noncurrent days calculations, see <a
* href="https://docs.aws.amazon.com/AmazonS3/latest/dev/intro-lifecycle-rules.html#non-current-days-calculations">How
@@ -29,60 +29,100 @@ namespace Model
/**
* <p>Specifies the number of days an object is noncurrent before Amazon S3 can
- * perform the associated action. For information about the noncurrent days
- * calculations, see <a
+ * perform the associated action. The value must be a non-zero positive integer.
+ * For information about the noncurrent days calculations, see <a
* href="https://docs.aws.amazon.com/AmazonS3/latest/dev/intro-lifecycle-rules.html#non-current-days-calculations">How
@@ -29,60 +29,100 @@ namespace Model
/**
* <p>Specifies the number of days an object is noncurrent before Amazon S3 can
- * perform the associated action. For information about the noncurrent days
- * calculations, see <a
+ * perform the associated action. The value must be a non-zero positive integer.
+ * For information about the noncurrent days calculations, see <a
* href="https://docs.aws.amazon.com/AmazonS3/latest/dev/intro-lifecycle-rules.html#non-current-days-calculations">How